@@ -10,7 +10,7 @@ bundled with tmuxp. Usage example:
 ...
 """
 
-import typing as t
+from __future__ import annotations
 
 from typing_extensions import NotRequired, TypedDict
 
@@ -26,10 +26,10 @@ class PluginTestConfigSchema(TypedDict):
     plugin_name: NotRequired[str]
     tmux_min_version: NotRequired[str]
     tmux_max_version: NotRequired[str]
-    tmux_version_incompatible: NotRequired[t.List[str]]
+    tmux_version_incompatible: NotRequired[list[str]]
     libtmux_min_version: NotRequired[str]
     libtmux_max_version: NotRequired[str]
-    libtmux_version_incompatible: NotRequired[t.List[str]]
+    libtmux_version_incompatible: NotRequired[list[str]]
     tmuxp_min_version: NotRequired[str]
     tmuxp_max_version: NotRequired[str]
-    tmuxp_version_incompatible: NotRequired[t.List[str]]
+    tmuxp_version_incompatible: NotRequired[list[str]]
