@@ -1,5 +1,7 @@
 """Tmuxp example plugin that fails on initialization."""
 
+from __future__ import annotations
+
 import typing as t
 
 from tmuxp.plugin import TmuxpPlugin
@@ -12,7 +14,7 @@ class PluginFailVersion(TmuxpPlugin):
     """A tmuxp plugin that is doomed to fail. DOOMED."""
 
     def __init__(self) -> None:
-        config: "PluginConfigSchema" = {
+        config: PluginConfigSchema = {
             "plugin_name": "tmuxp-plugin-fail-version",
             "tmuxp_max_version": "0.0.0",
         }
